@@ -16,7 +16,12 @@
 /*
    	The maximum width/height is MAXIMUM_SIZE 768*768 for now
 */
-#define MAXIMUM_SIZE 4096
+#define MAXIMUM_SIZE 8192
+/*
+    libavcodec doesn't recommend thread count > 16, but things start to fall apart already > 8
+    FIXME find a more suitable location
+*/
+#define LAVC_MAX_SAFE_THREAD_COUNT 8
 
 typedef unsigned char ADM_filename;
 
@@ -56,8 +61,7 @@ typedef unsigned char ADM_filename;
 #define uint32_t 	unsigned long  int
 #endif	// GOT_TYPES
 
-#define UNUSED_ARG(a) (void)a
-
+#define UNUSED_ARG(a) (void)(a)
 
 #define MKFCC(a,b,c,d)   ((d<<24)+(c<<16)+(b<<8)+a)
 #define MKFCCR(a,b,c,d)   ((a<<24)+(b<<16)+(c<<8)+d)
